@@ -39,6 +39,10 @@ from inspect_ai._util.registry import (
 from inspect_ai._util.working import init_sample_working_time, sample_waiting_time
 from inspect_ai._view.notify import view_notify_eval
 from inspect_ai.dataset import Dataset, Sample
+from inspect_ai.event._error import ErrorEvent
+from inspect_ai.event._sample_init import SampleInitEvent
+from inspect_ai.event._sample_limit import SampleLimitEvent
+from inspect_ai.event._score import ScoreEvent
 from inspect_ai.log import (
     EvalConfig,
     EvalError,
@@ -59,10 +63,6 @@ from inspect_ai.log._samples import (
     active_sample,
 )
 from inspect_ai.log._transcript import (
-    ErrorEvent,
-    SampleInitEvent,
-    SampleLimitEvent,
-    ScoreEvent,
     Transcript,
     init_transcript,
     transcript,
@@ -76,8 +76,12 @@ from inspect_ai.model import (
     ModelName,
 )
 from inspect_ai.model._model import init_sample_model_usage, sample_model_usage
+from inspect_ai.model._providers.providers import (
+    validate_anthropic_client,
+    validate_openai_client,
+)
 from inspect_ai.scorer import Scorer, Target
-from inspect_ai.scorer._metric import SampleScore
+from inspect_ai.scorer._metric import Metric, SampleScore
 from inspect_ai.scorer._reducer.types import ScoreReducer
 from inspect_ai.scorer._score import init_scoring_context
 from inspect_ai.scorer._scorer import unique_scorer_name
@@ -145,7 +149,10 @@ class TaskRunOptions:
 
 
 async def task_run(options: TaskRunOptions) -> EvalLog:
-    from inspect_ai.hooks._hooks import emit_task_end, emit_task_start
+    from inspect_ai.hooks._hooks import (
+        emit_task_end,
+        emit_task_start,
+    )
     from inspect_ai.hooks._legacy import send_telemetry_legacy
 
     # destructure options
@@ -166,7 +173,12 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
     generate_config = task.config.merge(GenerateConfigArgs(**kwargs))
 
     # init task context
-    init_task_context(model, model_roles, options.task.approval, generate_config)
+    init_task_context(
+        model,
+        model_roles,
+        generate_config,
+        options.task.approval,
+    )
 
     # track stats and error
     results: EvalResults | None = None
@@ -245,10 +257,11 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
     with display().task(
         profile,
     ) as td:
-        try:
-            # start the log
-            await log_start(logger, plan, generate_config)
+        # start the log (do this outside fo the try b/c the try/except assumes
+        # that the log is initialized)
+        await log_start(logger, plan, generate_config)
 
+        try:
             # return immediately if we are not running samples
             if not options.run_samples:
                 return await logger.log_finish("started", stats)
@@ -311,6 +324,7 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
                         progress_results,
                         scorers,
                         task.epochs_reducer,
+                        task.metrics,
                     )
 
                 # initial progress
@@ -322,6 +336,7 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
                     progress_results,
                     scorers,
                     task.epochs_reducer,
+                    task.metrics,
                 )
 
                 async def run_sample(
@@ -381,6 +396,7 @@ async def task_run(options: TaskRunOptions) -> EvalLog:
                     scores=completed_scores,
                     reducers=task.epochs_reducer,
                     scorers=scorers,
+                    metrics=task.metrics,
                 )
 
             # collect eval data
@@ -474,6 +490,7 @@ def update_metrics_display_fn(
         list[dict[str, SampleScore]],
         list[Scorer] | None,
         ScoreReducer | list[ScoreReducer] | None,
+        list[Metric | dict[str, list[Metric]]] | dict[str, list[Metric]] | None,
     ],
     None,
 ]:
@@ -484,6 +501,9 @@ def update_metrics_display_fn(
         sample_scores: list[dict[str, SampleScore]],
         scorers: list[Scorer] | None,
         reducers: ScoreReducer | list[ScoreReducer] | None,
+        metrics: list[Metric | dict[str, list[Metric]]]
+        | dict[str, list[Metric]]
+        | None,
     ) -> None:
         # Don't compute metrics if they are not being displayed
         if not display_metrics:
@@ -498,6 +518,7 @@ def update_metrics_display_fn(
                 scores=sample_scores,
                 reducers=reducers,
                 scorers=scorers,
+                metrics=metrics,
             )
 
             # Name, reducer, value
@@ -552,7 +573,11 @@ async def task_run_sample(
     run_id: str,
     task_id: str,
 ) -> dict[str, SampleScore] | None:
-    from inspect_ai.hooks._hooks import emit_sample_end, emit_sample_start
+    from inspect_ai.hooks._hooks import (
+        emit_sample_end,
+        emit_sample_scoring,
+        emit_sample_start,
+    )
 
     # if there is an existing sample then tick off its progress, log it, and return it
     if sample_source and sample.id is not None:
@@ -658,11 +683,13 @@ async def task_run_sample(
         raise_error: BaseException | None = None
         results: dict[str, SampleScore] = {}
         limit: EvalSampleLimit | None = None
-        try:
-            # begin init
-            init_span = span("init", type="init")
-            await init_span.__aenter__()
 
+        # begin init
+        init_span = span("init", type="init")
+        await init_span.__aenter__()
+        cleanup_span: contextlib.AbstractAsyncContextManager[None] | None = init_span
+
+        try:
             # sample init event (remove file bodies as they have content or absolute paths)
             event_sample = sample.model_copy(
                 update=dict(files={k: "" for k in sample.files.keys()})
@@ -681,6 +708,7 @@ async def task_run_sample(
                         active.sandboxes = await sandbox_connections()
                     finally:
                         await init_span.__aexit__(None, None, None)
+                        cleanup_span = None
 
                     # record start time
                     start_time = time.monotonic()
@@ -820,7 +848,7 @@ async def task_run_sample(
                     state = sample_state() or state
                     limit = EvalSampleLimit(type="operator", limit=1)
 
-                except BaseException as ex:
+                except Exception as ex:
                     error, raise_error = handle_error(ex)
 
                 # mark completed
@@ -840,6 +868,12 @@ async def task_run_sample(
                 solver_score_names = [*state.scores]
 
                 # scoring
+                await emit_sample_scoring(
+                    eval_set_id,
+                    run_id,
+                    task_id,
+                    state.uuid,
+                )
                 try:
                     # timeout during scoring will result in an ordinary sample error
                     with create_time_limit(scoring_time_limit):
@@ -859,21 +893,24 @@ async def task_run_sample(
                                             raise RuntimeError(
                                                 f"Scorer {scorer_name} has modified state.scores"
                                             )
-                                        state.scores[scorer_name] = score_result
+                                        if score_result is not None:
+                                            state.scores[scorer_name] = score_result
 
-                                        transcript()._event(
-                                            ScoreEvent(
-                                                score=score_result,
-                                                target=sample.target,
+                                            transcript()._event(
+                                                ScoreEvent(
+                                                    score=score_result,
+                                                    target=sample.target,
+                                                )
                                             )
-                                        )
 
-                                        results[scorer_name] = SampleScore(
-                                            score=score_result,
-                                            sample_id=sample.id,
-                                            sample_metadata=sample.metadata,
-                                            scorer=registry_unqualified_name(scorer),
-                                        )
+                                            results[scorer_name] = SampleScore(
+                                                score=score_result,
+                                                sample_id=sample.id,
+                                                sample_metadata=sample.metadata,
+                                                scorer=registry_unqualified_name(
+                                                    scorer
+                                                ),
+                                            )
 
                                 for name in solver_score_names:
                                     score = state.scores[name]
@@ -897,12 +934,15 @@ async def task_run_sample(
 
                     raise
 
-                except BaseException as ex:
+                except Exception as ex:
                     # handle error
                     error, raise_error = handle_error(ex)
 
         except Exception as ex:
             error, raise_error = handle_error(ex)
+        finally:
+            if cleanup_span is not None:
+                await cleanup_span.__aexit__(None, None, None)
 
         # complete the sample if there is no error or if there is no retry_on_error in play
         if not error or (retry_on_error == 0):
@@ -1026,6 +1066,7 @@ def create_eval_sample(
         store=dict(state.store.items()),
         uuid=state.uuid,
         events=list(transcript().events),
+        attachments=dict(transcript().attachments),
         model_usage=sample_model_usage(),
         total_time=round(total_time, 3) if total_time is not None else None,
         working_time=round(total_time - sample_waiting_time(), 3)
@@ -1173,6 +1214,8 @@ def create_sample_semaphore(
 
 def init_sample_assistant_internal() -> None:
     if importlib.util.find_spec("openai"):
+        validate_openai_client("OpenAI API")
+
         from inspect_ai.model._openai_responses import (
             init_sample_openai_assistant_internal,
         )
@@ -1180,6 +1223,8 @@ def init_sample_assistant_internal() -> None:
         init_sample_openai_assistant_internal()
 
     if importlib.util.find_spec("anthropic"):
+        validate_anthropic_client("Anthropic API")
+
         from inspect_ai.model._providers.anthropic import (
             init_sample_anthropic_assistant_internal,
         )
