@@ -1,6 +1,11 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
 from logging import getLogger
-from typing import Any, Awaitable, Callable, Sequence, cast
+from typing import TYPE_CHECKING, Any, Awaitable, Callable, Sequence, cast, overload
+
+if TYPE_CHECKING:
+    from inspect_ai.scorer._scorers import Scorers
 
 from pydantic import BaseModel
 from typing_extensions import TypedDict, Unpack
@@ -57,7 +62,7 @@ class Task:
         setup: Solver | list[Solver] | None = None,
         solver: Solver | Agent | list[Solver] = generate(),
         cleanup: Callable[[TaskState], Awaitable[None]] | None = None,
-        scorer: Scorer | list[Scorer] | None = None,
+        scorer: "Scorers" | None = None,
         metrics: list[Metric | dict[str, list[Metric]]]
         | dict[str, list[Metric]]
         | None = None,
@@ -209,7 +214,7 @@ def task_with(
     setup: Solver | list[Solver] | None | NotGiven = NOT_GIVEN,
     solver: Solver | list[Solver] | NotGiven = NOT_GIVEN,
     cleanup: Callable[[TaskState], Awaitable[None]] | None | NotGiven = NOT_GIVEN,
-    scorer: Scorer | list[Scorer] | None | NotGiven = NOT_GIVEN,
+    scorer: "Scorers" | None | NotGiven = NOT_GIVEN,
     metrics: list[Metric | dict[str, list[Metric]]]
     | dict[str, list[Metric]]
     | None
@@ -399,10 +404,36 @@ def resolve_solver(solver: Solver | Agent | list[Solver]) -> Solver:
         return cast(Solver, solver)
 
 
-def resolve_scorer(scorer: Scorer | list[Scorer] | None) -> list[Scorer] | None:
-    return (
-        scorer if isinstance(scorer, list) else [scorer] if scorer is not None else None
-    )
+@overload
+def resolve_scorer(scorer: "Scorers") -> list[Scorer]: ...
+
+
+@overload
+def resolve_scorer(scorer: None) -> None: ...
+
+
+def resolve_scorer(
+    scorer: "Scorers" | None = None,
+) -> list[Scorer] | None:
+    if scorer is None:
+        return scorer
+
+    scorers = list(scorer) if isinstance(scorer, Sequence) else [scorer]
+    return [to_scorer(s) for s in scorers]
+
+
+def to_scorer(s: Any) -> Scorer:
+    if is_registry_object(s, type="scanner"):
+        from inspect_scout import as_scorer
+
+        return as_scorer(s)
+    elif is_registry_object(s, type="scorer"):
+        return cast(Scorer, s)
+    else:
+        raise TypeError(f"Unexpected scorer type: {type(s)}")
+
+
+AGENT_DESCRIPTION = "description"
 
 
 def resolve_scorer_metrics(
