@@ -7,19 +7,21 @@ export const modelColumn = () => {
   return columnHelper.accessor(
     (row) => {
       if (row.type !== "file") return "";
-      return row.logOverview?.model || "";
+      return row.logPreview?.model || "";
     },
     {
       id: "model",
       header: "Model",
       cell: (info) => {
         const item = info.row.original;
-        if (item.type !== "file" || item.logOverview?.model === undefined) {
-          return <EmptyCell />;
+        if (item.type === "file" && item.logPreview?.model !== undefined) {
+          return (
+            <div className={styles.modelCell}>{item.logPreview.model}</div>
+          );
+        } else if (item.type === "pending-task" && item.model) {
+          return <div className={styles.modelCell}>{item.model}</div>;
         }
-        return (
-          <div className={styles.modelCell}>{item.logOverview.model || ""}</div>
-        );
+        return <EmptyCell />;
       },
       enableSorting: true,
       enableGlobalFilter: true,
