@@ -1,14 +1,15 @@
-import { useCallback } from "react";
+import { useCallback, useMemo } from "react";
 import { useNavigate, useSearchParams } from "react-router-dom";
 import { useFilteredSamples } from "../../state/hooks";
 import { useStore } from "../../state/store";
 import { directoryRelativeUrl } from "../../utils/uri";
+import { sampleIdsEqual } from "../shared/sample";
 import { logUrl, logUrlRaw, sampleUrl, useLogRouteParams } from "./url";
 
 export const useLogNavigation = () => {
   const navigate = useNavigate();
   const { logPath } = useLogRouteParams();
-  const logs = useStore((state) => state.logs.logs);
+  const logDir = useStore((state) => state.logs.logDir);
   const loadedLog = useStore((state) => state.log.loadedLog);
 
   const selectTab = useCallback(
@@ -20,11 +21,11 @@ export const useLogNavigation = () => {
         navigate(url);
       } else if (loadedLog) {
         // Fallback to constructing the path if needed
-        const url = logUrl(loadedLog, logs.log_dir, tabId);
+        const url = logUrl(loadedLog, logDir, tabId);
         navigate(url);
       }
     },
-    [loadedLog, logPath, logs.log_dir, navigate],
+    [loadedLog, logPath, logDir, navigate],
   );
 
   return {
@@ -35,7 +36,7 @@ export const useLogNavigation = () => {
 export const useSampleUrl = () => {
   const { logPath, tabId, sampleTabId } = useLogRouteParams();
 
-  const logDirectory = useStore((state) => state.logs.logs.log_dir);
+  const logDirectory = useStore((state) => state.logs.logDir);
 
   const selectedLogFile = useStore((state) => state.logs.selectedLogFile);
 
@@ -86,7 +87,7 @@ export const useSampleNavigation = () => {
   const navigate = useNavigate();
 
   // The log directory
-  const logDirectory = useStore((state) => state.logs.logs.log_dir);
+  const logDirectory = useStore((state) => state.logs.logDir);
 
   // The log
   const { logPath, tabId, sampleTabId } = useLogRouteParams();
@@ -112,9 +113,19 @@ export const useSampleNavigation = () => {
   const sampleSummaries = useFilteredSamples();
 
   // Sample hooks
-  const selectedSampleIndex = useStore(
-    (state) => state.log.selectedSampleIndex,
+  const selectedSampleHandle = useStore(
+    (state) => state.log.selectedSampleHandle,
   );
+
+  const selectedSampleIndex = useMemo(() => {
+    return sampleSummaries.findIndex((summary) => {
+      return (
+        sampleIdsEqual(summary.id, selectedSampleHandle?.id) &&
+        summary.epoch === selectedSampleHandle?.epoch
+      );
+    });
+  }, [selectedSampleHandle, sampleSummaries]);
+
   const selectSample = useStore((state) => state.logActions.selectSample);
   const setShowingSampleDialog = useStore(
     (state) => state.appActions.setShowingSampleDialog,
@@ -123,17 +134,12 @@ export const useSampleNavigation = () => {
 
   // Navigate to a specific sample with index
   const showSample = useCallback(
-    (
-      index: number,
-      id: string | number,
-      epoch: number,
-      specifiedSampleTabId?: string,
-    ) => {
+    (id: string | number, epoch: number, specifiedSampleTabId?: string) => {
       const resolvedPath = resolveLogPath();
 
       if (resolvedPath) {
         // Update internal state
-        selectSample(index);
+        selectSample(id, epoch);
         setShowingSampleDialog(true);
 
         // Use specified sampleTabId if provided, otherwise use current sampleTabId from URL params
@@ -174,12 +180,13 @@ export const useSampleNavigation = () => {
             navigate(url);
           }
         } else {
-          selectSample(index);
+          const summary = sampleSummaries[index];
+          selectSample(summary.id, summary.epoch);
         }
       }
     },
     [
-      selectedSampleIndex,
+      selectedSampleHandle,
       showSample,
       sampleTabId,
       sampleSummaries,
