@@ -34,8 +34,8 @@ import {
 } from "../../constants";
 import {
   useDocumentTitle,
-  useFilteredSamples,
   useSampleData,
+  useSelectedSampleSummary,
 } from "../../state/hooks";
 import { useStore } from "../../state/store";
 import { formatTime } from "../../utils/format";
@@ -70,10 +70,6 @@ export const SampleDisplay: FC<SampleDisplayProps> = ({
 }) => {
   // Tab ids
   const baseId = `sample-dialog`;
-  const filteredSamples = useFilteredSamples();
-  const selectedSampleIndex = useStore(
-    (state) => state.log.selectedSampleIndex,
-  );
 
   const sampleData = useSampleData();
   const sample = useMemo(() => {
@@ -82,7 +78,7 @@ export const SampleDisplay: FC<SampleDisplayProps> = ({
 
   const runningSampleData = sampleData.running;
 
-  const evalSpec = useStore((state) => state.log.selectedLogSummary?.eval);
+  const evalSpec = useStore((state) => state.log.selectedLogDetails?.eval);
   const { setDocumentTitle } = useDocumentTitle();
   useEffect(() => {
     setDocumentTitle({ evalSpec, sample });
@@ -111,9 +107,7 @@ export const SampleDisplay: FC<SampleDisplayProps> = ({
     return -1;
   }, [tabsRef.current]);
 
-  const sampleSummary = useMemo(() => {
-    return filteredSamples[selectedSampleIndex];
-  }, [filteredSamples, selectedSampleIndex]);
+  const selectedSampleSummary = useSelectedSampleSummary();
 
   // Consolidate the events and messages into the proper list
   // whether running or not
@@ -192,6 +186,19 @@ export const SampleDisplay: FC<SampleDisplayProps> = ({
     setDisplayMode(displayMode === "rendered" ? "raw" : "rendered");
   }, [displayMode, setDisplayMode]);
 
+  const collapsedMode = useStore((state) => state.sample.collapsedMode);
+  const setCollapsedMode = useStore(
+    (state) => state.sampleActions.setCollapsedMode,
+  );
+
+  const isCollapsed = (mode: "collapsed" | "expanded" | null) => {
+    return mode === "collapsed"; //null is expanded
+  };
+
+  const toggleCollapsedMode = useCallback(() => {
+    setCollapsedMode(isCollapsed(collapsedMode) ? "expanded" : "collapsed");
+  }, [collapsedMode, setCollapsedMode]);
+
   const { isDebugFilter, isDefaultFilter } = useTranscriptFilter();
 
   const tools = [];
@@ -211,6 +218,19 @@ export const SampleDisplay: FC<SampleDisplayProps> = ({
         ref={filterRef}
       />,
     );
+
+    tools.push(
+      <ToolButton
+        key="sample-collapse-transcript"
+        label={isCollapsed(collapsedMode) ? "Expand" : "Collapse"}
+        icon={
+          isCollapsed(collapsedMode)
+            ? ApplicationIcons.expand.all
+            : ApplicationIcons.collapse.all
+        }
+        onClick={toggleCollapsedMode}
+      />,
+    );
   }
 
   tools.push(
@@ -237,15 +257,16 @@ export const SampleDisplay: FC<SampleDisplayProps> = ({
 
   // Is the sample running?
   const running = useMemo(() => {
-    return isRunning(sampleSummary, runningSampleData);
-  }, [sampleSummary, runningSampleData]);
+    return isRunning(selectedSampleSummary, runningSampleData);
+  }, [selectedSampleSummary, runningSampleData]);
 
   const sampleDetailNavigation = useSampleDetailNavigation();
+  const displaySample = sample || selectedSampleSummary;
 
   return (
     <Fragment>
-      {sample || sampleSummary ? (
-        <SampleSummaryView parent_id={id} sample={sample || sampleSummary} />
+      {displaySample ? (
+        <SampleSummaryView parent_id={id} sample={displaySample} />
       ) : undefined}
       <TabSet
         id={tabsetId}
