@@ -9,6 +9,7 @@ import {
   ContentImage,
   ContentText,
   EvalSample,
+  EvalSet,
   InfoEvent,
   LoggerEvent,
   ModelEvent,
@@ -24,16 +25,14 @@ import {
 } from "../@types/log";
 import {
   AttachmentData,
-  EvalLogHeader,
-  EvalSummary,
+  EvalHeader,
   EventData,
-  LogFile,
-  LogFiles,
-  LogOverview,
+  LogDetails,
+  LogHandle,
+  LogPreview,
   PendingSamples,
   SampleSummary,
 } from "../client/api/types";
-import { ScorerInfo } from "../state/scoring";
 
 export interface AppState {
   status: AppStatus;
@@ -66,14 +65,19 @@ export interface AppState {
 }
 
 export interface LogsState {
-  logs: LogFiles;
-  logOverviews: Record<string, LogOverview>;
-  logOverviewsLoading: boolean;
-  selectedLogIndex: number;
+  logDir?: string;
+  logs: LogHandle[];
+  logPreviews: Record<string, LogPreview>;
+  logDetails: Record<string, LogDetails>;
+  evalSet?: EvalSet;
   selectedLogFile?: string;
   listing: LogsListing;
-  loadingFiles: Set<string>;
-  pendingRequests: Map<string, Promise<EvalLogHeader | null>>;
+  pendingRequests: Map<string, Promise<EvalHeader | null>>;
+  dbStats: {
+    logCount: number;
+    previewCount: number;
+    detailsCount: number;
+  };
 }
 
 export interface LogsListing {
@@ -83,14 +87,20 @@ export interface LogsListing {
   columnResizeMode?: ColumnResizeMode;
   columnSizes?: Record<string, number>;
   filteredCount?: number;
-  watchedLogs?: LogFile[];
+  watchedLogs?: LogHandle[];
+  selectedRowIndex?: number | null;
+}
+
+export interface SampleHandle {
+  id: string | number;
+  epoch: number;
 }
 
 export interface LogState {
   loadedLog?: string;
 
-  selectedSampleIndex: number;
-  selectedLogSummary?: EvalSummary;
+  selectedSampleHandle?: SampleHandle;
+  selectedLogDetails?: LogDetails;
   pendingSampleSummaries?: PendingSamples;
 
   filter: string;
@@ -98,8 +108,8 @@ export interface LogState {
 
   epoch: string;
   sort: string;
-  score?: ScoreLabel;
-  scores?: ScorerInfo[];
+  selectedScores?: ScoreLabel[];
+  scores?: ScoreLabel[];
 }
 
 export type SampleStatus = "ok" | "loading" | "streaming" | "error";
@@ -127,6 +137,7 @@ export interface SampleState {
   runningEvents: Event[];
   collapsedEvents: Record<string, Record<string, boolean>> | null;
   collapsedIdBuckets: Record<string, Record<string, boolean>>;
+  collapsedMode: "collapsed" | "expanded" | null;
   eventFilter: EventFilter;
 
   selectedOutlineId?: string;
@@ -150,13 +161,17 @@ export type Event =
   | SubtaskEvent;
 
 export interface AppStatus {
-  loading: boolean;
+  // Waiting while loading data, show large form of progress
+  loading: number;
+
+  // Background syncing data, show small form of activity
+  syncing: boolean;
   error?: Error;
 }
 
 export interface CurrentLog {
   name: string;
-  contents: EvalSummary;
+  contents: LogDetails;
 }
 
 export interface Logs {
