@@ -1,5 +1,5 @@
 import { StateSnapshot } from "react-virtuoso";
-import { AppState, AppStatus } from "../app/types";
+import { AppState } from "../app/types";
 import { Capabilities } from "../client/api/types";
 import { kLogViewSamplesTabId, kSampleTranscriptTabId } from "../constants";
 import { clearDocumentSelection } from "../utils/browser";
@@ -9,7 +9,7 @@ export interface AppSlice {
   app: AppState;
   capabilities: Capabilities;
   appActions: {
-    setStatus: (status: AppStatus) => void;
+    setLoading: (loading: boolean, error?: Error) => void;
     setShowFind: (show: boolean) => void;
     hideFind: () => void;
 
@@ -72,7 +72,7 @@ const kDefaultWorkspaceTab = kLogViewSamplesTabId;
 const kDefaultSampleTab = kSampleTranscriptTabId;
 
 const initialState: AppState = {
-  status: { loading: false },
+  status: { loading: 0, syncing: false },
   showFind: false,
   dialogs: {
     sample: false,
@@ -117,9 +117,13 @@ export const createAppSlice = (
 
     // Actions
     appActions: {
-      setStatus: (status: AppStatus) =>
+      setLoading: (loading: boolean, error?: Error) =>
         set((state) => {
-          state.app.status = status;
+          state.app.status.loading = Math.max(
+            state.app.status.loading + (loading ? 1 : -1),
+            0,
+          );
+          state.app.status.error = error;
         }),
 
       setShowFind: (show: boolean) =>
