@@ -1,13 +1,8 @@
-import asyncio
 import os
-import sys
-import traceback
 from logging import getLogger
 from types import TracebackType
-from typing import Any, Literal, Tuple, Type, TypedDict
+from typing import Any, Literal, Type, TypedDict
 
-import click
-import tenacity
 from pydantic import (
     BaseModel,
     ConfigDict,
@@ -15,24 +10,25 @@ from pydantic import (
     PrivateAttr,
     model_validator,
 )
-from rich.console import Console, RenderableType
-from rich.traceback import Traceback
+from rich.console import Console
 from shortuuid import uuid
 
-from inspect_ai._util.constants import CONSOLE_DISPLAY_WIDTH, DESERIALIZING, PKG_NAME
+from inspect_ai._util.constants import DESERIALIZING
 from inspect_ai._util.error import EvalError, exception_message
 from inspect_ai._util.hash import base57_id_hash
 from inspect_ai._util.json import to_json_str_safe
 from inspect_ai._util.logger import warn_once
 from inspect_ai._util.metadata import MT, metadata_as
+from inspect_ai._util.rich import rich_traceback, truncate_traceback
 from inspect_ai.approval._policy import ApprovalPolicyConfig
 from inspect_ai.model import ChatMessage, GenerateConfig, ModelOutput, ModelUsage
+from inspect_ai.model._model_config import ModelConfig
 from inspect_ai.scorer import Score
 from inspect_ai.util._sandbox.environment import SandboxEnvironmentSpec
 from inspect_ai.util._store import Store
 from inspect_ai.util._store_model import SMT
 
-from ._transcript import Event
+from ..event._event import Event
 from ._util import thin_input, thin_metadata, thin_text
 
 logger = getLogger(__name__)
@@ -161,9 +157,11 @@ class EvalConfig(BaseModel):
     @model_validator(mode="before")
     @classmethod
     def convert_max_messages_to_message_limit(
-        cls: Type["EvalConfig"], values: dict[str, Any]
-    ) -> dict[str, Any]:
+        cls: Type["EvalConfig"], values: Any
+    ) -> Any:
         """Migrate deprecated max_messages property."""
+        if not isinstance(values, dict):
+            return values
         max_messages = values.get("max_messages", None)
         if max_messages:
             values["message_limit"] = max_messages
@@ -198,10 +196,10 @@ class EvalSampleSummary(BaseModel):
     """Sample target value(s)"""
 
     metadata: dict[str, Any] = Field(default_factory=dict)
-    """Sample metadata (scalar types only, strings truncated to 1k)."""
+    """Sample metadata (only fields < 1k; strings truncated to 1k)."""
 
     scores: dict[str, Score] | None = Field(default=None)
-    """Scores for sample (score values only, no answers, explanations, or metadata)."""
+    """Scores for sample (only metadata fields < 1k; strings truncated to 1k)."""
 
     model_usage: dict[str, ModelUsage] = Field(default_factory=dict)
     """Model token usage for sample."""
@@ -227,6 +225,9 @@ class EvalSampleSummary(BaseModel):
     completed: bool = Field(default=False)
     """Is the sample complete."""
 
+    message_count: int | None = Field(default=None)
+    """Number of messages in the sample conversation."""
+
     @model_validator(mode="after")
     def thin_data(self) -> "EvalSampleSummary":
         # thin input
@@ -395,6 +396,7 @@ class EvalSample(BaseModel):
             limit=f"{self.limit.type}" if self.limit is not None else None,
             retries=len(self.error_retries) if self.error_retries is not None else None,
             completed=True,
+            message_count=len(self.messages),
         )
 
     # deprecated properties
@@ -420,9 +422,9 @@ class EvalSample(BaseModel):
 
     @model_validator(mode="before")
     @classmethod
-    def migrate_deprecated(
-        cls: Type["EvalSample"], values: dict[str, Any]
-    ) -> dict[str, Any]:
+    def migrate_deprecated(cls: Type["EvalSample"], values: Any) -> Any:
+        if not isinstance(values, dict):
+            return values
         if "score" in values:
             # There cannot be a scorers property too
             if "scores" in values:
@@ -606,9 +608,9 @@ class EvalResults(BaseModel):
 
     @model_validator(mode="before")
     @classmethod
-    def convert_scorer_to_scorers(
-        cls: Type["EvalResults"], values: dict[str, Any]
-    ) -> dict[str, Any]:
+    def convert_scorer_to_scorers(cls: Type["EvalResults"], values: Any) -> Any:
+        if not isinstance(values, dict):
+            return values
         if "scorer" in values:
             # There cannot be a scorers property too
             if "scores" in values:
@@ -690,21 +692,8 @@ class EvalRevision(BaseModel):
     commit: str
     """Revision commit."""
 
-
-class EvalModelConfig(BaseModel):
-    """Model config."""
-
-    model: str
-    """Model name."""
-
-    config: GenerateConfig = Field(default_factory=GenerateConfig)
-    """Generate config"""
-
-    base_url: str | None = Field(default=None)
-    """Model base url."""
-
-    args: dict[str, Any] = Field(default_factory=dict)
-    """Model specific arguments."""
+    dirty: bool | None = Field(default=None)
+    """Working tree has uncommitted changes or untracked files."""
 
 
 class EvalSpec(BaseModel):
@@ -776,7 +765,7 @@ class EvalSpec(BaseModel):
     model_args: dict[str, Any] = Field(default_factory=dict)
     """Model specific arguments."""
 
-    model_roles: dict[str, EvalModelConfig] | None = Field(default=None)
+    model_roles: dict[str, ModelConfig] | None = Field(default=None)
     """Model roles."""
 
     config: EvalConfig
@@ -795,7 +784,9 @@ class EvalSpec(BaseModel):
     """Scorers and args for this eval"""
 
     metrics: (
-        list[EvalMetricDefinition] | dict[str, list[EvalMetricDefinition]] | None
+        list[EvalMetricDefinition | dict[str, list[EvalMetricDefinition]]]
+        | dict[str, list[EvalMetricDefinition]]
+        | None
     ) = Field(default=None)
     """metrics and args for this eval"""
 
@@ -819,9 +810,9 @@ class EvalSpec(BaseModel):
 
     @model_validator(mode="before")
     @classmethod
-    def read_sandbox_spec(
-        cls: Type["EvalSpec"], values: dict[str, Any]
-    ) -> dict[str, Any]:
+    def read_sandbox_spec(cls: Type["EvalSpec"], values: Any) -> Any:
+        if not isinstance(values, dict):
+            return values
         return migrate_values(values)
 
 
@@ -862,65 +853,6 @@ def eval_error(
     )
 
 
-def rich_traceback(
-    exc_type: Type[Any], exc_value: BaseException, exc_traceback: TracebackType | None
-) -> RenderableType:
-    rich_tb = Traceback.from_exception(
-        exc_type=exc_type,
-        exc_value=exc_value,
-        traceback=exc_traceback,
-        suppress=[click, asyncio, tenacity, sys.modules[PKG_NAME]],
-        show_locals=os.environ.get("INSPECT_TRACEBACK_LOCALS", None) == "1",
-        width=CONSOLE_DISPLAY_WIDTH,
-    )
-    return rich_tb
-
-
-def truncate_traceback(
-    exc_type: Type[Any],
-    exc_value: BaseException,
-    exc_traceback: TracebackType | None,
-    max_length: int = 1048576,  # 1MB
-) -> Tuple[str, bool]:
-    tb_list = traceback.format_exception(exc_type, exc_value, exc_traceback)
-
-    # Keep the front and back of the traceback
-    header = tb_list[0]
-    error_msg = tb_list[-1]
-
-    # Join the middle parts (stack frames)
-    frames = "".join(tb_list[1:-1])
-
-    # It all fits, use it as is
-    full_tb = header + frames + error_msg
-    if len(full_tb) <= max_length:
-        return full_tb, False
-
-    ellipsis = "\n...\n"
-
-    # Minimum header size
-    header_size = min(len(header), 1024)
-
-    # Minimum frames size
-    frames_size = min(len(frames), 1024)
-
-    # Remaining space for error message
-    error_msg_size = max(0, max_length - header_size - frames_size)
-
-    def truncate_middle(text: str, size: int) -> str:
-        if len(text) <= size:
-            return text
-        half = (size - len(ellipsis)) // 2
-        return f"{text[:half]}{ellipsis}{text[-half:]}"
-
-    # Truncate each part as needed
-    truncated_header = truncate_middle(header, header_size)
-    truncated_frames = truncate_middle(frames, frames_size)
-    truncated_error = truncate_middle(error_msg, error_msg_size)
-
-    return truncated_header + truncated_frames + truncated_error, True
-
-
 class EvalStats(BaseModel):
     """Timing and usage statistics."""
 
@@ -992,9 +924,9 @@ class EvalLog(BaseModel):
 
     @model_validator(mode="before")
     @classmethod
-    def resolve_sample_reductions(
-        cls: Type["EvalLog"], values: dict[str, Any]
-    ) -> dict[str, Any]:
+    def resolve_sample_reductions(cls: Type["EvalLog"], values: Any) -> Any:
+        if not isinstance(values, dict):
+            return values
         has_reductions = "reductions" in values
         has_results = values.get("results", None) is not None
         has_sample_reductions = has_results and (
