@@ -12,6 +12,7 @@ from inspect_ai._util.content import (
     ContentToolUse,
     ContentVideo,
 )
+from inspect_ai._util.json import to_json_str_safe
 from inspect_ai.model._chat_message import ChatMessage
 
 # the maximum length of summary inputs
@@ -67,11 +68,21 @@ def truncate_text(text: str, max_length: int = MAX_TEXT_LENGTH) -> str:
     return text
 
 
+def thin_text(text: str) -> str:
+    return textwrap.shorten(text, width=1024, placeholder="...")
+
+
 def thin_metadata(metadata: dict[str, Any]) -> dict[str, Any]:
     thinned: dict[str, Any] = {}
     for key, value in metadata.items():
         if isinstance(value, int | float | bool | date | time | datetime):
             thinned[key] = value
         elif isinstance(value, str):
-            thinned[key] = textwrap.shorten(value, width=1024, placeholder="...")
+            thinned[key] = thin_text(value)
+        else:
+            size = len(to_json_str_safe(value))
+            if size <= 1024:
+                thinned[key] = value
+            else:
+                thinned[key] = "Key removed from summary (> 1k)"
     return thinned
