@@ -1,6 +1,7 @@
 import inspect
 import json
 import types
+import typing
 from copy import copy, deepcopy
 from dataclasses import is_dataclass
 from datetime import date, datetime, time
@@ -13,6 +14,7 @@ from typing import (
     Callable,
     Dict,
     List,
+    Literal,
     NamedTuple,
     Optional,
     Sequence,
@@ -112,7 +114,8 @@ async def execute_tools(
     """
     message = messages[-1]
     if isinstance(message, ChatMessageAssistant) and message.tool_calls:
-        from inspect_ai.log._transcript import ToolEvent, transcript
+        from inspect_ai.event._tool import ToolEvent
+        from inspect_ai.log._transcript import transcript
 
         tdefs = await tool_defs(tools)
 
@@ -343,7 +346,8 @@ async def call_tool(
     conversation: list[ChatMessage],
 ) -> tuple[ToolResult, list[ChatMessage], ModelOutput | None, str | None]:
     from inspect_ai.agent._handoff import AgentTool
-    from inspect_ai.log._transcript import ToolEvent, transcript
+    from inspect_ai.event._tool import ToolEvent
+    from inspect_ai.log._transcript import transcript
 
     # dodge circular import
     assert isinstance(event, ToolEvent)
@@ -655,7 +659,9 @@ def tool_param(type_hint: Type[Any], input: Any) -> Any:
     args = get_args(type_hint)
 
     if origin is None:
-        if type_hint in [int, str, float, bool]:
+        if type_hint == typing.Any:
+            return input
+        elif type_hint in [int, str, float, bool]:
             try:
                 return type_hint(input)
             except (ValueError, TypeError):
@@ -778,7 +784,11 @@ def tool_parse_error_message(arguments: str, ex: Exception) -> str:
 
 
 def parse_tool_call(
-    id: str, function: str, arguments: str, tools: list[ToolInfo] | None = None
+    id: str,
+    function: str,
+    arguments: str,
+    tools: list[ToolInfo] | None = None,
+    type: Literal["function", "custom"] = "function",
 ) -> ToolCall:
     """Parse a tool call from a JSON payload.
 
@@ -825,10 +835,7 @@ def parse_tool_call(
 
     # return ToolCall with error payload
     return ToolCall(
-        id=id,
-        function=function,
-        arguments=arguments_dict,
-        parse_error=error,
+        id=id, function=function, arguments=arguments_dict, parse_error=error, type=type
     )
 
 
