@@ -2,14 +2,19 @@ import json
 from contextvars import ContextVar
 from dataclasses import dataclass, field
 from functools import reduce
-from typing import Any, Protocol, Sequence, TypeGuard, cast
+from typing import Any, Iterable, Protocol, Sequence, TypeGuard, cast
 
 from openai.types.responses import (
     ComputerToolParam,
+    CustomToolParam,
     EasyInputMessageParam,
     FunctionToolParam,
     ResponseComputerToolCall,
     ResponseComputerToolCallParam,
+    ResponseCustomToolCall,
+    ResponseCustomToolCallOutputParam,
+    ResponseCustomToolCallParam,
+    ResponseFunctionCallOutputItemListParam,
     ResponseFunctionToolCall,
     ResponseFunctionToolCallParam,
     ResponseFunctionWebSearch,
@@ -39,10 +44,16 @@ from openai.types.responses.response import IncompleteDetails
 from openai.types.responses.response_create_params import (
     ToolChoice as ResponsesToolChoiceParam,
 )
+from openai.types.responses.response_custom_tool_call_output_param import (
+    OutputOutputContentList,
+)
 from openai.types.responses.response_function_web_search_param import (
     Action,
     ActionSearch,
 )
+from openai.types.responses.response_input_image_content_param import (
+    ResponseInputImageContentParam,
+)
 from openai.types.responses.response_input_item_param import (
     ComputerCallOutput,
     FunctionCallOutput,
@@ -55,6 +66,9 @@ from openai.types.responses.response_input_item_param import (
 from openai.types.responses.response_input_item_param import (
     McpListToolsTool as McpListToolsToolParam,
 )
+from openai.types.responses.response_input_text_content_param import (
+    ResponseInputTextContentParam,
+)
 from openai.types.responses.response_output_item import (
     McpCall,
     McpListTools,
@@ -71,6 +85,7 @@ from openai.types.responses.response_output_text import (
 from openai.types.responses.response_output_text_param import (
     Annotation as AnnotationParam,
 )
+from openai.types.responses.response_reasoning_item_param import Content as ContentParam
 from openai.types.responses.response_reasoning_item_param import Summary as SummaryParam
 from openai.types.responses.response_usage import (
     InputTokensDetails,
@@ -97,6 +112,7 @@ from inspect_ai.model._call_tools import parse_tool_call
 from inspect_ai.model._chat_message import (
     ChatMessage,
     ChatMessageAssistant,
+    ChatMessageTool,
 )
 from inspect_ai.model._generate_config import GenerateConfig
 from inspect_ai.model._model_output import ChatCompletionChoice, ModelUsage, StopReason
@@ -120,6 +136,8 @@ class ResponsesModelInfo(Protocol):
     def has_reasoning_options(self) -> bool: ...
     def is_gpt(self) -> bool: ...
     def is_gpt_5(self) -> bool: ...
+    def is_gpt_5_pro(self) -> bool: ...
+    def is_gpt_5_chat(self) -> bool: ...
     def is_o_series(self) -> bool: ...
     def is_o1(self) -> bool: ...
     def is_o1_early(self) -> bool: ...
@@ -130,25 +148,21 @@ class ResponsesModelInfo(Protocol):
 
 
 async def openai_responses_inputs(
-    messages: list[ChatMessage], model_info: ResponsesModelInfo
+    messages: list[ChatMessage],
 ) -> list[ResponseInputItemParam]:
     return [
         item
         for message in messages
-        for item in await _openai_input_item_from_chat_message(message, model_info)
+        for item in await _openai_input_item_from_chat_message(message)
     ]
 
 
 async def _openai_input_item_from_chat_message(
-    message: ChatMessage, model_info: ResponsesModelInfo
+    message: ChatMessage,
 ) -> list[ResponseInputItemParam]:
     if message.role == "system":
         content = await _openai_responses_content_list_param(message.content)
-        return (
-            [Message(type="message", role="developer", content=content)]
-            if model_info.is_o_series() or model_info.is_gpt_5()
-            else [Message(type="message", role="system", content=content)]
-        )
+        return [Message(type="message", role="developer", content=content)]
     elif message.role == "user":
         return [
             Message(
@@ -169,21 +183,86 @@ async def _openai_input_item_from_chat_message(
             and responses_tool_call["type"] == "computer_call"
         ):
             return [computer_call_output(message, responses_tool_call["call_id"])]
-
-        return [
-            FunctionCallOutput(
-                type="function_call_output",
-                call_id=message.tool_call_id or str(message.function),
-                output=message.error.message
-                if message.error is not None
-                else message.text,
-            )
-        ]
+        elif (
+            responses_tool_call is not None
+            and responses_tool_call["type"] == "custom_tool_call"
+        ):
+            return [
+                ResponseCustomToolCallOutputParam(
+                    type="custom_tool_call_output",
+                    call_id=message.tool_call_id or str(message.function),
+                    output=message.error.message
+                    if message.error is not None
+                    else await _openai_responses_custom_tool_call_output(message),
+                )
+            ]
+        else:
+            return [
+                FunctionCallOutput(
+                    type="function_call_output",
+                    call_id=message.tool_call_id or str(message.function),
+                    output=message.error.message
+                    if message.error is not None
+                    else await _openai_responses_function_call_output(message),
+                )
+            ]
 
     else:
         raise ValueError(f"Unexpected message role '{message.role}'")
 
 
+async def _openai_responses_function_call_output(
+    message: ChatMessageTool,
+) -> str | ResponseFunctionCallOutputItemListParam:
+    if isinstance(message.content, str):
+        return message.content
+    else:
+        outputs: ResponseFunctionCallOutputItemListParam = []
+        for c in message.content:
+            if isinstance(c, ContentText):
+                outputs.append(
+                    ResponseInputTextContentParam(type="input_text", text=c.text)
+                )
+            elif isinstance(c, ContentImage):
+                outputs.append(
+                    ResponseInputImageContentParam(
+                        type="input_image",
+                        detail=c.detail,
+                        image_url=(
+                            c.image
+                            if is_http_url(c.image)
+                            else await file_as_data_uri(c.image)
+                        ),
+                    )
+                )
+        return outputs
+
+
+async def _openai_responses_custom_tool_call_output(
+    message: ChatMessageTool,
+) -> str | Iterable[OutputOutputContentList]:
+    if isinstance(message.content, str):
+        return message.content
+    else:
+        outputs: list[OutputOutputContentList] = []
+        for c in message.content:
+            if isinstance(c, ContentText):
+                outputs.append(ResponseInputTextParam(type="input_text", text=c.text))
+            elif isinstance(c, ContentImage):
+                outputs.append(
+                    ResponseInputImageParam(
+                        type="input_image",
+                        detail=c.detail,
+                        image_url=(
+                            c.image
+                            if is_http_url(c.image)
+                            else await file_as_data_uri(c.image)
+                        ),
+                    )
+                )
+        return outputs
+
+
 async def _openai_responses_content_list_param(
     content: str | list[Content],
 ) -> ResponseInputMessageContentListParam:
@@ -322,7 +401,10 @@ def is_native_tool_configured(
 @dataclass
 class _AssistantInternal:
     tool_calls: dict[
-        str, ResponseFunctionToolCallParam | ResponseComputerToolCallParam
+        str,
+        ResponseFunctionToolCallParam
+        | ResponseCustomToolCallParam
+        | ResponseComputerToolCallParam,
     ] = field(default_factory=dict)
     server_tool_uses: dict[str, ResponseInputItemParam] = field(default_factory=dict)
 
@@ -346,8 +428,9 @@ def content_from_response_input_content_param(
     if is_input_text(input):
         return ContentText(text=input["text"])
     elif is_input_image(input):
-        assert input["image_url"]
-        return ContentImage(image=input["image_url"], detail=input["detail"])
+        return ContentImage(
+            image=input.get("image_url", "") or "", detail=input.get("detail", "auto")
+        )
     elif is_input_file(input):
         return ContentDocument(document=input["file_data"], filename=input["filename"])
     else:
@@ -457,6 +540,20 @@ def _chat_message_assistant_from_openai_response(
                         tools,
                     )
                 )
+            case ResponseCustomToolCall():
+                stop_reason = "tool_calls"
+                if output.id is not None:
+                    assistant_internal().tool_calls[output.call_id] = cast(
+                        ResponseCustomToolCallParam, output.model_dump()
+                    )
+                tool_call = ToolCall(
+                    id=output.call_id,
+                    function=output.name,
+                    arguments={"input": output.input},
+                    type="custom",
+                )
+                tool_calls.append(tool_call)
+
             case ResponseComputerToolCall():
                 stop_reason = "tool_calls"
                 if output.id is not None:
@@ -505,12 +602,21 @@ def reasoning_from_responses_reasoning(
         reasoning = item.encrypted_content
         redacted = True
     else:
-        reasoning = "\n".join([s.text for s in item.summary])
-        if item.content is not None:
-            reasoning = f"{reasoning}\n" + "\n".join([s.text for s in item.content])
+        reasoning = (
+            "\n".join([s.text for s in item.content])
+            if item.content is not None
+            else ""
+        )
         redacted = False
 
-    return ContentReasoning(reasoning=reasoning, signature=item.id, redacted=redacted)
+    if item.summary:
+        summary: str | None = "\n\n".join([s.text for s in item.summary])
+    else:
+        summary = None
+
+    return ContentReasoning(
+        reasoning=reasoning, summary=summary, signature=item.id, redacted=redacted
+    )
 
 
 # two issues addressed here:
@@ -519,7 +625,7 @@ def reasoning_from_responses_reasoning(
 def read_reasoning_item_param(
     param: ResponseReasoningItemParam,
 ) -> ResponseReasoningItem:
-    no_id = "id" not in param
+    no_id = param.get("id", None) is None
     if no_id:
         param = param.copy()
         param["id"] = "dummy-id"
@@ -532,19 +638,26 @@ def read_reasoning_item_param(
 def responses_reasoning_from_reasoning(
     content: ContentReasoning,
 ) -> ResponseReasoningItemParam:
-    summary: list[SummaryParam] = []
+    content_params: list[ContentParam] = []
     if content.redacted:
         encrypted_content: str | None = content.reasoning
     else:
         encrypted_content = None
         if content.reasoning:
-            summary.append(SummaryParam(type="summary_text", text=content.reasoning))
+            content_params.append(
+                ContentParam(type="reasoning_text", text=content.reasoning)
+            )
+
+    summary_params: list[SummaryParam] = []
+    if content.summary:
+        summary_params.append(SummaryParam(type="summary_text", text=content.summary))
 
     return ResponseReasoningItemParam(
         type="reasoning",
         # OpenAI returns 'None' when store=False even though the schema requires the id
         id=content.signature,  # type: ignore[typeddict-item]
-        summary=summary,
+        content=content_params,
+        summary=summary_params,
         encrypted_content=encrypted_content,
     )
 
@@ -827,15 +940,26 @@ def _tool_param_for_tool_info(
     model_name: str,
     config: GenerateConfig,
 ) -> ToolParam:
-    # Use a native tool implementation when available. Otherwise, use the
-    # standard tool implementation
-    return _maybe_native_tool_param(tool, model_name, config) or FunctionToolParam(
-        type="function",
-        name=_responses_tool_alias(tool.name),
-        description=tool.description,
-        parameters=tool.parameters.model_dump(exclude_none=True),
-        strict=False,  # default parameters don't work in strict mode
-    )
+    # Use a native tool implementation when available.
+    tool_param = _maybe_native_tool_param(tool, model_name, config)
+    if tool_param is not None:
+        return tool_param
+
+    if tool.options is not None and "custom_format" in tool.options:
+        return CustomToolParam(
+            type="custom",
+            name=tool.name,
+            description=tool.description,
+            format=tool.options["custom_format"],
+        )
+    else:
+        return FunctionToolParam(
+            type="function",
+            name=_responses_tool_alias(tool.name),
+            description=tool.description,
+            parameters=tool.parameters.model_dump(exclude_none=True),
+            strict=False,  # default parameters don't work in strict mode
+        )
 
 
 # these functions enables us to 'escape' built in tool names like 'python'
@@ -925,7 +1049,9 @@ def is_input_file(
 def is_response_input_message(
     param: ResponseInputItemParam,
 ) -> TypeGuard[Message | EasyInputMessageParam]:
-    return param["type"] == "message" and not is_response_output_message(param)
+    return (
+        "role" in param and "content" in param and not is_response_output_message(param)
+    )
 
 
 def is_function_call_output(
@@ -934,6 +1060,12 @@ def is_function_call_output(
     return param["type"] == "function_call_output"
 
 
+def is_custom_tool_call_output(
+    param: ResponseInputItemParam,
+) -> TypeGuard[ResponseCustomToolCallOutputParam]:
+    return param["type"] == "custom_tool_call_output"
+
+
 def is_computer_call_output(
     param: ResponseInputItemParam,
 ) -> TypeGuard[ComputerCallOutput]:
@@ -943,11 +1075,12 @@ def is_computer_call_output(
 def is_assistant_message_param(
     param: ResponseInputItemParam,
 ) -> bool:
-    return (
+    return "type" in param and (
         is_response_output_message(param)
         or is_response_computer_tool_call(param)
         or is_response_web_search_call(param)
         or is_response_function_tool_call(param)
+        or is_response_custom_tool_call(param)
         or is_response_reasoning_item(param)
         or is_response_mcp_list_tools(param)
         or is_response_mcp_call(param)
@@ -958,7 +1091,8 @@ def is_response_output_message(
     param: ResponseInputItemParam,
 ) -> TypeGuard[ResponseOutputMessageParam]:
     return (
-        param["type"] == "message"
+        "type" in param
+        and param["type"] == "message"
         and param["role"] == "assistant"
         and isinstance(param.get("content", None), list)
         and any(
@@ -1016,6 +1150,12 @@ def is_response_mcp_call(
     return param["type"] == "mcp_call"
 
 
+def is_response_custom_tool_call(
+    param: ResponseInputItemParam,
+) -> TypeGuard[ResponseCustomToolCallParam]:
+    return param["type"] == "custom_tool_call"
+
+
 def is_function_tool_param(tool_param: ToolParam) -> TypeGuard[FunctionToolParam]:
     return tool_param.get("type") == "function"
 
@@ -1030,3 +1170,7 @@ def is_mcp_tool_param(tool_param: ToolParam) -> TypeGuard[Mcp]:
 
 def is_computer_tool_param(tool_param: ToolParam) -> TypeGuard[ComputerToolParam]:
     return tool_param.get("type") == "computer_use_preview"
+
+
+def is_custom_tool_param(tool_param: ToolParam) -> TypeGuard[CustomToolParam]:
+    return tool_param.get("type") == "custom"
