@@ -113,7 +113,7 @@ class AzureAIAPI(ModelAPI):
         # resolve api_key or managed identity (for Azure)
         self.token_provider = None
         self.api_key = os.environ.get(
-            AZURE_API_KEY, os.environ.get(AZUREAI_API_KEY, "")
+            AZURE_API_KEY, os.environ.get(AZUREAI_API_KEY, None)
         )
         if not self.api_key:
             # try managed identity (Microsoft Entra ID)
@@ -282,6 +282,12 @@ class AzureAIAPI(ModelAPI):
         else:
             return False
 
+    @override
+    def is_auth_failure(self, ex: Exception) -> bool:
+        if isinstance(ex, HttpResponseError):
+            return ex.status_code == 401
+        return False
+
     @override
     def collapse_user_messages(self) -> bool:
         return True
