@@ -1,3 +1,4 @@
+import base64
 import functools
 import hashlib
 import json
@@ -84,7 +85,10 @@ from inspect_ai.model._generate_config import normalized_batch_config
 from inspect_ai.model._model import log_model_retry
 from inspect_ai.model._model_call import ModelCall
 from inspect_ai.model._providers._google_batch import GoogleBatcher
-from inspect_ai.model._providers._google_citations import get_candidate_citations
+from inspect_ai.model._providers._google_citations import (
+    distribute_citations_to_text_parts,
+    get_candidate_citations,
+)
 from inspect_ai.model._retry import model_retry_config
 from inspect_ai.tool import (
     ToolCall,
@@ -378,6 +382,11 @@ class GoogleGenAIAPI(ModelAPI):
     def is_gemini_thinking_only(self) -> bool:
         return self.is_gemini_2_5() and "-pro" in self.service_model_name()
 
+    @override
+    def emulate_reasoning_history(self) -> bool:
+        # older gemini models don't know about reasoning
+        return self.is_gemini_1_5() or self.is_gemini_2_0()
+
     @override
     def should_retry(self, ex: BaseException) -> bool:
         if isinstance(ex, APIError) and ex.code is not None:
@@ -450,8 +459,8 @@ class GoogleGenAIAPI(ModelAPI):
         )
 
     def _categorize_tool(
-        self, acc: tuple[bool, list[FunctionDeclaration]], tool: ToolInfo
-    ) -> tuple[bool, list[FunctionDeclaration]]:
+        self, acc: tuple[GoogleSearch | None, list[FunctionDeclaration]], tool: ToolInfo
+    ) -> tuple[GoogleSearch | None, list[FunctionDeclaration]]:
         """Reducer function that categorizes tools into native search vs function declarations.
 
         Returns:
@@ -460,8 +469,8 @@ class GoogleGenAIAPI(ModelAPI):
             all non-native-search tools converted to FunctionDeclaration objects.
         """
         return (
-            (True, acc[1])
-            if self._use_native_search(tool)
+            (self._google_search_options(tool.options), acc[1])
+            if tool.options and self._use_native_search(tool)
             else (
                 acc[0],
                 acc[1]
@@ -477,21 +486,29 @@ class GoogleGenAIAPI(ModelAPI):
             )
         )
 
+    def _google_search_options(self, options: dict[str, Any]) -> GoogleSearch:
+        gemini_options = options.get("gemini", None)
+        if isinstance(gemini_options, dict):
+            return GoogleSearch.model_validate(gemini_options)
+        else:
+            return GoogleSearch()
+
     def chat_tools(self, tools: list[ToolInfo]) -> tuple[bool, ToolListUnion]:
-        has_native_search, function_declarations = functools.reduce(
-            self._categorize_tool, tools, (False, list[FunctionDeclaration]())
+        seed: GoogleSearch | None = None
+        google_search, function_declarations = functools.reduce(
+            self._categorize_tool, tools, (seed, list[FunctionDeclaration]())
         )
 
         # TODO: Google doesn't yet support native search concurrently with other tools.
         # Revisit this from time to time to adapt when they fix it.
-        if has_native_search and function_declarations:
+        if google_search and function_declarations:
             raise ValueError(
                 "Gemini does not yet support native search concurrently with other tools."
             )
 
         return (
-            (True, [Tool(google_search=GoogleSearch())])
-            if has_native_search
+            (True, [Tool(google_search=google_search)])
+            if google_search
             else (False, [Tool(function_declarations=function_declarations)])
         )
 
@@ -623,6 +640,7 @@ async def content(
     client: Client,
     message: ChatMessageUser | ChatMessageAssistant | ChatMessageTool,
 ) -> Content:
+    working_reasoning_block = None
     if isinstance(message, ChatMessageUser):
         if isinstance(message.content, str):
             return Content(
@@ -636,27 +654,75 @@ async def content(
         )
     elif isinstance(message, ChatMessageAssistant):
         content_parts: list[Part] = []
-        # tool call parts
-        if message.tool_calls is not None:
-            content_parts.extend(
-                [
-                    Part.from_function_call(
-                        name=tool_call.function,
-                        args=tool_call.arguments,
-                    )
-                    for tool_call in message.tool_calls
-                ]
-            )
 
-        # content parts
         if isinstance(message.content, str):
             content_parts.append(Part(text=message.content or NO_CONTENT))
         else:
-            content_parts.extend(
-                [await content_part(client, content) for content in message.content]
-            )
+            for i, content in enumerate(message.content):
+                if isinstance(content, ContentReasoning):
+                    # if this is encrytped reasoning, emit the part and save the
+                    # content block for applying the thought_signature to the next part
+                    if content.redacted:
+                        content_parts.append(
+                            Part(
+                                text=content.summary,
+                                thought=True,
+                            )
+                        )
+                        working_reasoning_block = content
+                    else:
+                        content_parts.append(Part(text=content.reasoning, thought=True))
 
-        # return parts
+                else:
+                    part_to_append = await content_part(client, content)
+                    # If previously there was a reasoning block, we need to set the "thought_signature"
+                    # using the reasoning from that block.
+                    if working_reasoning_block is not None:
+                        if (
+                            working_reasoning_block.reasoning is not None
+                            and working_reasoning_block.redacted
+                        ):
+                            part_to_append.thought_signature = base64.b64decode(
+                                working_reasoning_block.reasoning.encode()
+                            )
+                        else:
+                            logger.warning(
+                                "Reasoning block must have a reasoning signature to set thought_signature."
+                            )
+                        # Now, reset the previous reasoning block.
+                        working_reasoning_block = None
+                    content_parts.append(part_to_append)
+
+        # Now handle tool calls
+        if message.tool_calls is not None:
+            # Note that if each tool call had its own reasoning block in a message with
+            # multiple reasoning blocks, we wouldn't know which reasoning block corresponded
+            # to which tool call. That said, to date we have not observed Gemini using
+            # a reasoning block per-tool so this isn't likely a practical concern
+            for tool_call in message.tool_calls:
+                # extract the part
+                part = Part.from_function_call(
+                    name=tool_call.function,
+                    args=tool_call.arguments,
+                )
+
+                # handle reasoning block if available
+                if working_reasoning_block is not None:
+                    # tool call reasoning should always use a thought_signature
+                    if (
+                        working_reasoning_block.reasoning is not None
+                        and working_reasoning_block.redacted
+                    ):
+                        part.thought_signature = base64.b64decode(
+                            working_reasoning_block.reasoning.encode()
+                        )
+                    else:
+                        logger.warning(
+                            "Reasoning block must have a reasoning signature to set thought_signature."
+                        )
+                    working_reasoning_block = None
+
+                content_parts.append(part)
         return Content(role="model", parts=content_parts)
 
     elif isinstance(message, ChatMessageTool):
@@ -677,11 +743,7 @@ async def content_part(client: Client, content: InspectContent | str) -> Part:
     elif isinstance(content, ContentText):
         return Part.from_text(text=content.text or NO_CONTENT)
     elif isinstance(content, ContentReasoning):
-        return Part(
-            text=content.reasoning or NO_CONTENT,
-            thought=True,
-            thought_signature=content.signature.encode() if content.signature else None,
-        )
+        raise RuntimeError("content_part should never encounter ContentReasoning")
     elif isinstance(content, ContentData):
         raise RuntimeError("Google provider should never encounter ContentData")
     elif isinstance(content, ContentToolUse):
@@ -830,53 +892,74 @@ def chat_tool_config(tool_choice: ToolChoice) -> ToolConfig:
 def completion_choice_from_candidate(
     model: str, candidate: Candidate
 ) -> ChatCompletionChoice:
-    # content can be None when the finish_reason is SAFETY
-    if candidate.content is None:
-        content: (
-            str
-            | list[
-                ContentText
-                | ContentReasoning
-                | ContentImage
-                | ContentToolUse
-                | ContentAudio
-                | ContentVideo
-                | ContentData
-                | ContentDocument
-            ]
-        ) = ""
-    # content.parts can be None when the finish_reason is MALFORMED_FUNCTION_CALL
-    elif candidate.content.parts is None:
-        content = ""
-    else:
-        # Google's grounded search metadata provides start/end indices for cited
-        # text based on the joining of all separate text parts (despite the doc
-        # suggesting that they provide part_index). Thankfully, the doc also says:
-        #
-        #   Exactly one field within a Part should be set, representing the specific type
-        #   of content being conveyed. Using multiple fields within the same `Part`
-        #   instance is considered invalid.
-        #
-        # That means that we can safely collapse adjacent parts with a `text` field
-        # and not fear that we're breaking other types of content parts
-        parts = functools.reduce(
-            _combine_text_parts, candidate.content.parts, list[Part]()
-        )
+    # content we'll return
+    content: list[
+        ContentText
+        | ContentReasoning
+        | ContentImage
+        | ContentToolUse
+        | ContentAudio
+        | ContentVideo
+        | ContentData
+        | ContentDocument
+    ] = []
 
-        content = [
-            ContentReasoning(
-                reasoning=part.text,
-                signature=part.thought_signature.decode()
-                if part.thought_signature
-                else None,
-            )
-            if part.thought is True
-            else ContentText(
-                text=part.text, citations=get_candidate_citations(candidate)
-            )
-            for part in parts
-            if part.text is not None
-        ]
+    # google distributes reasoning text and thought_signature across multiple
+    # content parts -- we need to consolidate this into a single ContentReasoning
+    # to match our schema (we'll unroll it back into parts on replay)
+    working_reasoning_block: ContentReasoning | None = None
+
+    # content can be None when the finish_reason is SAFETY
+    # content.parts can be None when the finish_reason is MALFORMED_FUNCTION_CALL
+    if candidate.content is not None and candidate.content.parts is not None:
+        # traverse parts
+        parts = candidate.content.parts
+        for i, part in enumerate(parts):
+            if part.text is None:
+                continue  # We only care about text parts here
+
+            if part.thought is True:
+                # we'll create and append a reasoning block, saving a reference
+                # to it so that we can ammend it with a thought signature if/when
+                # one arrives later in the stream (note that multiple reasoning
+                # parts without a signature can occur)
+                working_reasoning_block = ContentReasoning(
+                    reasoning=part.text,
+                    redacted=False,
+                )
+                content.append(working_reasoning_block)
+            else:
+                # Check if this block has an associated thought_signature and
+                # whether it corresponds to the previous ContentReasoning block.
+                if part.thought_signature is not None:
+                    if working_reasoning_block is None:
+                        # append the reasoning block to the list
+                        content.append(
+                            ContentReasoning(
+                                reasoning=base64.b64encode(
+                                    part.thought_signature
+                                ).decode(),
+                                redacted=True,
+                            )
+                        )
+                    elif working_reasoning_block is not None:
+                        # attach the though_signature to the previous reasoning block
+                        working_reasoning_block.summary = (
+                            working_reasoning_block.reasoning
+                        )
+                        working_reasoning_block.reasoning = base64.b64encode(
+                            part.thought_signature
+                        ).decode()
+                        working_reasoning_block.redacted = True
+                        # clear it out
+                        working_reasoning_block = None
+
+                content.append(ContentText(text=part.text))
+
+    # distribute citations to individual ContentText parts with adjusted indexes
+    citations = get_candidate_citations(candidate)
+    if citations:
+        distribute_citations_to_text_parts(content, citations)
 
     # now tool calls
     tool_calls: list[ToolCall] = []
@@ -884,20 +967,42 @@ def completion_choice_from_candidate(
         for part in candidate.content.parts:
             if part.function_call:
                 if (
-                    part.function_call is not None
-                    and part.function_call.name is not None
-                    and part.function_call.args is not None
+                    part.function_call is None
+                    or part.function_call.name is None
+                    or part.function_call.args is None
                 ):
-                    tool_calls.append(
-                        ToolCall(
-                            id=f"{part.function_call.name}_{uuid()}",
-                            function=part.function_call.name,
-                            arguments=part.function_call.args,
-                        )
-                    )
-                else:
                     raise ValueError(f"Incomplete function call: {part.function_call}")
 
+                # If the part has a thought_signature, try and associate it with the previous working block
+                if part.thought_signature:
+                    if working_reasoning_block is None:
+                        # We make the assumption that tool calls don't have independent reasoning
+                        # blocks unless they are preceded by a reasoning block.
+                        reasoning_block = ContentReasoning(
+                            reasoning=base64.b64encode(part.thought_signature).decode(),
+                            redacted=True,
+                        )
+
+                        content.append(reasoning_block)
+                    else:
+                        # attach the though_signature to the previous reasoning block
+                        working_reasoning_block.summary = (
+                            working_reasoning_block.reasoning
+                        )
+                        working_reasoning_block.reasoning = base64.b64encode(
+                            part.thought_signature
+                        ).decode()
+                        working_reasoning_block.redacted = True
+                        working_reasoning_block = None
+
+                tool_calls.append(
+                    ToolCall(
+                        id=f"{part.function_call.name}_{uuid()}",
+                        function=part.function_call.name,
+                        arguments=part.function_call.args,
+                    )
+                )
+
     # stop reason
     stop_reason = finish_reason_to_stop_reason(
         candidate.finish_reason or FinishReason.STOP
@@ -906,7 +1011,7 @@ def completion_choice_from_candidate(
     # build choice
     choice = ChatCompletionChoice(
         message=ChatMessageAssistant(
-            content=content,
+            content=content if len(content) > 0 else "",
             tool_calls=tool_calls if len(tool_calls) > 0 else None,
             model=model,
             source="generate",
@@ -1132,16 +1237,3 @@ async def file_for_content(
         files_db.put(content_sha256, str(upload.name))
         # return the file
         return upload
-
-
-def _combine_text_parts(acc: list[Part], part: Part) -> list[Part]:
-    """Combine adjacent text parts into a single part."""
-    return (
-        acc + [part]
-        if part.text is None
-        or part.thought is True
-        or len(acc) == 0
-        or acc[-1].text is None
-        or acc[-1].thought is True
-        else acc[:-1] + [Part(text=acc[-1].text + part.text)]
-    )
