@@ -240,6 +240,9 @@ class MistralAPI(ModelAPI):
         """Model name without any service prefix."""
         return self.model_name.replace(f"{self.service}/", "", 1)
 
+    def canonical_name(self) -> str:
+        return self.service_model_name()
+
     @override
     def should_retry(self, ex: Exception) -> bool:
         if isinstance(ex, SDKError):
@@ -253,6 +256,12 @@ class MistralAPI(ModelAPI):
     def connection_key(self) -> str:
         return str(self.api_key)
 
+    @override
+    def is_auth_failure(self, ex: Exception) -> bool:
+        if isinstance(ex, SDKError):
+            return ex.status_code == 401
+        return False
+
     def handle_bad_request(self, ex: SDKError) -> ModelOutput | Exception:
         body = json.loads(ex.body)
         content = body.get("message", ex.body)
