@@ -95,7 +95,7 @@ async def generate_responses(
         else NOT_GIVEN
     )
     request = dict(
-        input=await openai_responses_inputs(input, model_info),
+        input=await openai_responses_inputs(input),
         tools=tool_params,
         tool_choice=openai_responses_tool_choice(tool_choice, tool_params)
         if isinstance(tool_params, list) and tool_choice != "auto"
@@ -234,16 +234,13 @@ def completion_params_responses(
 
     # responses_store may have been specified in config.extra_body
     # (e.g. by a client talking to us through the agent bridge)
-    if config.extra_body and "store" in config.extra_body:
+    if responses_store is None and config.extra_body and "store" in config.extra_body:
         responses_store = config.extra_body["store"]
 
-    if responses_store is False:
-        if model_info.is_computer_use_preview():
-            raise RuntimeError(
-                "OpenAI computer use model requires responses store=True"
-            )
+    if responses_store is not True:
         params["store"] = False
-        params["include"] = ["reasoning.encrypted_content"]
+        if model_info.has_reasoning_options() or model_info.is_computer_use_preview():
+            params["include"] = ["reasoning.encrypted_content"]
 
     if config.max_tokens is not None:
         params["max_output_tokens"] = config.max_tokens
@@ -312,4 +309,8 @@ def completion_params_responses(
             if field in config.extra_body and field not in params:
                 params[field] = config.extra_body[field]
 
+    # remove metadata if store is true
+    if responses_store is True:
+        params.pop("metadata", None)
+
     return params
