@@ -16,9 +16,8 @@ async def span(name: str, *, type: str | None = None) -> AsyncIterator[None]:
         name (str): Step name.
         type (str | None): Optional span type.
     """
+    from inspect_ai.event._span import SpanBeginEvent, SpanEndEvent
     from inspect_ai.log._transcript import (
-        SpanBeginEvent,
-        SpanEndEvent,
         track_store_changes,
         transcript,
     )
