@@ -38,7 +38,7 @@ async def check_stop_reason(model_name, **model_args: Any):
 @skip_if_no_groq
 @skip_if_trio
 async def test_groq_stop_reason() -> None:
-    await check_stop_reason("groq/llama3-70b-8192")
+    await check_stop_reason("groq/openai/gpt-oss-20b")
 
 
 @pytest.mark.asyncio
